@@ -1,5 +1,6 @@
 from .file_associations import *
 from .transform import *
+from abstract_pandas.abstractLandManager import *
 import logging
 class SingletonMeta(type):
     _instances = {}
@@ -164,11 +165,11 @@ class shapeManager(metaclass=SingletonMeta):
         if row is not None:
             row = row.to_dict()
             geom = row.get('geometry')
-            logging.info(f"Derived geometry for point: {geom}")
+            logging.info(f"Derived geometry for {value}")
         geom = geom or self.get_polygon(designation, value)
         if point_js.get('from') == 'center':
             geom = geom.centroid
-        logging.info(f"Derived geometry for point: {point_js}")
+
         point_js['geom'] = geom
         return point_js
 
